@@ -539,7 +539,8 @@ class EllipsoidPlot(BasePlot):
         ############################################################################################################################
         ############################################################################################################################
 
-        from matplotlib import pyplot as plt
+        import matplotlib.pyplot as plt
+        plt.ion() # turn on the interactive mode. Used to detach the figure from the command line in ipython
 
         ############################################################################################################################
         #### generate figure and axes if needed
